# Generated by Django 2.1.3 on 2018-11-27 15:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        ("filepond", "0002_auto_20181127_0925"),
    ]

    operations = [
        migrations.AddField(
            model_name="upload",
            name="content_type",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="contenttypes.ContentType",
            ),
        ),
        migrations.AddField(
            model_name="upload",
            name="object_id",
            field=models.PositiveIntegerField(blank=True, null=True),
        ),
    ]
