# Generated by Django 2.1.3 on 2018-11-27 15:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("filepond", "0001_initial")]

    operations = [
        migrations.AlterField(
            model_name="upload",
            name="original",
            field=models.FileField(upload_to="uploads"),
        )
    ]
